#!/bin/bash

# variables availables (from gerrit plugin)
# GERRIT_NAME / GERRIT_PORT: host/port usable for ssh
# GERRIT_PROJECT: job name e.g. alpine/abos-base
# GERRIT_REFSPEC: Reference in gerrit e.g. refs/changes/13/13/2
# GERRIT_PATCHSET_REVISON: commit id for current commit,
#                          also checked out as GIT_COMMIT by git plugin

# for tests:
PUBLISH=true
[ -n "$GERRIT_PORT" ] \
	&& [ -n "$GERRIT_NAME" ] \
	&& [ -n "$GERRIT_PROJECT" ] \
	&& [ -n "$GERRIT_PATCHSET_REVISION" ] \
	|| PUBLISH=false
TESTDIR=$(dirname "$0")


set -o pipefail


publish_checkpatch() {
	local SSH_GERRIT="ssh -p $GERRIT_PORT $GERRIT_NAME"
	if [[ "$PUBLISH" == "true" ]]; then
		tee /proc/$$/fd/1 | $SSH_GERRIT \
			"gerrit review --json --project $GERRIT_PROJECT $GERRIT_PATCHSET_REVISION"
	else
		echo "Would have submit:"
		echo -n "echo '"
		cat
		echo -n "' | $SSH_GERRIT "
		echo "\"gerrit review --json --project $GERRIT_PROJECT $GERRIT_PATCHSET_REVISION\""
	fi
}

# current commit already checked out
git show --format=email      | \
	( cd "$TESTDIR/checkpatch" && ./checkpatch.pl -q - || true ) | \
	python "$TESTDIR/checkpatch/checkpatch-to-gerrit-json.py"    | \
	publish_checkpatch


# final checks: note unless the job is silent, jenkins will give ±1 verified from exit status
# in this case checks don't pass on jenkins node so run in alpine docker...
docker run -v "$PWD:/work" \
	--rm --env "uidgid=$(id -u):$(id -g)" \
	"alpine-3.16-x86_64" sh -c \
		'sed -i -e "s/builder:x:[0-9]*:[0-9]*/builder:x:${uidgid}/" /etc/passwd &&
		apk add zlib-dev bash coreutils &&
		exec su builder -c "cd /work && make check"'
